pub enum Wire {
Detector(Heartbeat),
Announce(NewEpoch),
Refuse(Nack),
}Expand description
The wire, multiplexing the three children the book names.
Variants
Detector(Heartbeat)
The leader detector’s heartbeats.
Announce(NewEpoch)
sbeb — the announcements.
Refuse(Nack)
sl — the refusals, which go to one process rather than all.