pub struct LoggedEpochChange { /* private fields */ }Expand description
A sequence of epochs whose current position survives a restart.
Implementations
Sourceimpl LoggedEpochChange
impl LoggedEpochChange
Sourcepub fn new(
me: NodeId,
peers: impl IntoIterator<Item = NodeId>,
timing: Timing,
) -> Self
pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, timing: Timing, ) -> Self
Epoch-change among peers, over a leader detector with the given heartbeat and timeout and
stubborn children retransmitting every retransmit.
Sourcepub fn last_timestamp(&self) -> u64
pub fn last_timestamp(&self) -> u64
startts — the epoch this process has entered, as its durable record has it.
Sourcepub fn last_leader(&self) -> NodeId
pub fn last_leader(&self) -> NodeId
start — who leads the epoch this process has entered.